@@ -10,6 +10,8 @@
 //! - the implementations of [`PartialEq`] and [`PartialOrd`] against
 //!   [`String`](alloc::string::String) for [`StaticString`]
 //! - the implementation of [`Error`](std::error::Error) for [`StringError`]
+//! - the `bounds_to_string` function unique to this crate and implemented by several of the
+//!   iterators in it
 
 #![no_std]
 #![allow(
@@ -1238,6 +1240,37 @@ impl<T, const N: usize> StaticVec<T, N> {
     Self { data: res, length }
   }
 
+  /// Provides the same sorting functionality as
+  /// [`quicksorted_unstable`](crate::StaticVec::quicksorted_unstable) (and has the same trait
+  /// bound requirements) but operates in-place on the calling StaticVec instance rather than
+  /// returning the sorted data in a new one.
+  ///
+  /// Example usage:
+  /// ```
+  /// # use staticvec::*;
+  /// let mut v = staticvec![5.0, 4.0, 3.0, 2.0, 1.0];
+  /// v.quicksort_unstable();
+  /// assert_eq!(v, [1.0, 2.0, 3.0, 4.0, 5.0]);
+  /// // Note that if you are actually sorting floating-point numbers as shown above, and the
+  /// // StaticVec contains one or more instances of NAN, the "accuracy" of the sorting will
+  /// // essentially be determined by a combination of how many *consecutive* NANs there are,
+  /// // as well as how "mixed up" the surrounding valid numbers were to begin with. In any case,
+  /// // the outcome of this particular hypothetical scenario will never be any worse than the
+  /// // values simply not being sorted quite as you'd hoped.
+  /// ```
+  #[inline]
+  pub fn quicksort_unstable(&mut self)
+  where T: Copy + PartialOrd {
+    let length = self.length;
+    if length < 2 {
+      return;
+    }
+    let self_ptr = self.as_mut_ptr();
+    // We know self_ptr will never be null, so this is a safe hint to give the optimizer.
+    unsafe { intrinsics::assume(!is_null_mut(self_ptr)) };
+    quicksort_internal(self_ptr, 0, (length - 1) as isize);
+  }
+
   /// Returns a separate, reversed StaticVec of the contents of the StaticVec's inhabited area
   /// without modifying the original data. Locally requires that `T` implements
   /// [`Copy`](core::marker::Copy) to avoid soundness issues.
@@ -2313,6 +2346,9 @@ impl<const N: usize> StaticVec<u8, N> {
       to: To,
     }
     // As stated above, this is effectively doing what `MaybeUninit::assume_init()` does.
+    // Note that while it might "look scary", what this function actually does would be incredibly
+    // mundane in basically any other language: you would just declare a very normal static array,
+    // and use it, very normally. That's literally *all* this is.
     let mut res = unsafe {
       Convert::<MaybeUninit<[MaybeUninit<u8>; N]>, [MaybeUninit<u8>; N]> {
         from: MaybeUninit::uninit(),
